#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_I0_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_I0_HPP_INCLUDED

#include <nt2/bessel/include/functions/scalar/i0.hpp>

#endif
